@@ -73,9 +73,6 @@ SExpDesignUIWidgets ()
         g_object_ref( (GObject*)mFFTParamsBinSize);
         g_object_ref( (GObject*)mFFTParamsWindowType);
 
-      // misc
-        auto font_desc = pango_font_description_from_string( "Mono 9");
-
         GtkTreeViewColumn *col;
 
       // =========== 1. Measurements
@@ -300,7 +297,9 @@ SExpDesignUIWidgets ()
         AGH_GBGETOBJ (wScanLog);
         AGH_GBGETOBJ (tScanLog);
 
-        gtk_widget_override_font( (GtkWidget*)tScanLog, font_desc);
+        agh::ui::global::set_mono_font(
+                (GtkWidget*)tScanLog, agh::ui::global::css_mono8);
+        // gtk_widget_override_font( (GtkWidget*)tScanLog, font_desc);
         gtk_text_buffer_create_tag(
                 gtk_text_view_get_buffer( tScanLog),
                 "bold",
@@ -528,7 +527,9 @@ SExpDesignUIWidgets ()
         // used by two GtkTextView's, lEDFFileDetailsReport and lEdfImportFileInfo
         AGH_GBGETOBJ (tEDFFileDetailsReport);
 
-        gtk_widget_override_font( (GtkWidget*)lEDFFileDetailsReport, font_desc);
+        agh::ui::global::set_mono_font(
+                (GtkWidget*)lEDFFileDetailsReport, agh::ui::global::css_mono8);
+        // gtk_widget_override_font( (GtkWidget*)lEDFFileDetailsReport, font_desc);
         g_object_set( lEDFFileDetailsReport,
                       "tabs", pango_tab_array_new_with_positions(
                               2, TRUE,
@@ -552,8 +553,6 @@ SExpDesignUIWidgets ()
         AGH_GBGETOBJ (bEdfImportAdmit);
         AGH_GBGETOBJ (bEdfImportEdfhed);
 
-        gtk_widget_override_font( (GtkWidget*)lEdfImportFileInfo, font_desc);
-
         g_object_set( lEdfImportFileInfo,
                       "tabs", pango_tab_array_new_with_positions(
                                 2, TRUE,
@@ -651,8 +650,6 @@ SExpDesignUIWidgets ()
         gtk_combo_box_set_model_properly(
                 eGlobalADProfiles, mGlobalADProfiles);
         G_CONNECT_1 (eGlobalADProfiles, changed);
-
-        pango_font_description_free( font_desc);
 }
 
 
