@@ -19,6 +19,7 @@
 #include "libmetrics/mc-artifacts.hh"
 #include "libmetrics/bands.hh"
 //#include "aghermann/expdesign/expdesign.hh"
+#include "aghermann/globals.hh"
 #include "aghermann/model/beersma.hh"
 #include "aghermann/ui/misc.hh"
 #include "aghermann/ui/sf/sf.hh"
@@ -82,8 +83,8 @@ create_cprofile()
                 tl_start = csubject.measurements[*_p._p._AghDi].episodes.front().start_rel;
         } catch (...) {  // can be invalid_argument (no recording in such session/channel) or some TSimPrepError
                 cprofile = nullptr;
-                fprintf( stderr, "SSubjectPresentation::SSubjectPresentation(): subject \"%s\" has no recordings in session \"%s\" channel \"%s\"\n",
-                         csubject.id.c_str(), _p._p.AghD(), _p._p.AghT());
+                APPLOG_WARN ("SSubjectPresentation::SSubjectPresentation(): subject \"%s\" has no recordings in session \"%s\" channel \"%s\"\n",
+                             csubject.id.c_str(), _p._p.AghD(), _p._p.AghT());
         }
 }
 
@@ -374,11 +375,26 @@ do_purge_computed()
         SBusyBlock bb (wMainWindow);
 
         if ( ED->purge_cached_profiles() ) {
-                fprintf( stderr, "Command '%s' returned a non-zero status. This is suspicious.\n", ui::global::buf);
+                APPLOG_WARN( "Command '%s' returned a non-zero status. This is suspicious.\n", ui::global::buf);
                 sb_message( "Failed to purge cache files. This is odd.");
-        }
+        } else
+                sb_message( "Purged computed files cache");
+}
 
-        sb_message( "Purged computed files cache");
+
+void
+SExpDesignUI::
+do_delete_all_montages()
+{
+        SBusyBlock bb (wMainWindow);
+
+        snprintf_buf( "find '%s' -name '.*.montage' -delete",
+                      ED->session_dir());
+        if ( system( global::buf) ) {
+                APPLOG_WARN( "Command '%s' returned a non-zero status. This is suspicious.\n", ui::global::buf);
+                sb_message( "Failed to purge cache files. This is odd.");
+        } else
+                sb_message( "Reset all montages");
 }
 
 
